<?php $TRANSLATIONS = array(
"Music" => "Glazba",
"songs" => "pjesme",
"albums" => "albumi",
"Add album to playlist" => "Dodaj album u popis pjesama",
"Play" => "Reprodukcija",
"Pause" => "Pauza",
"Previous" => "Prethodna",
"Next" => "Sljedeća",
"Mute" => "Utišaj zvuk",
"Unmute" => "Uključi zvuk",
"Rescan Collection" => "Ponovi skeniranje kolekcije",
"Artist" => "Izvođač",
"Album" => "Album",
"Title" => "Naslov"
);
